@@ -133,6 +133,7 @@ class report(controllers.BaseController):
         return result
 
     def getDirectoriesChecks(self, row):
+        self.logger.debug("report: Getting directories checks")
         newRow = []
         newRow.append(row['dir'])
         self.logger.info(row)
@@ -196,22 +197,26 @@ class report(controllers.BaseController):
         return newRow
 
     def setTableTitle(self, pdf):
+        self.logger.debug("report: Updating table title")
         pdf.set_font('RobotoLight', '', 10)
         pdf.set_margins(10, 0, 10)
         pdf.set_fill_color(255, 255, 255)
         pdf.set_text_color(11, 11, 11)
 
     def setBlueHeaderStyle(self, pdf):
+        self.logger.debug("report: Updating blue header style")
         pdf.set_font('RobotoLight', '', 8)
         pdf.set_fill_color(73, 156, 254)
         pdf.set_text_color(255, 255, 255)
 
     def setTableRowStyle(self, pdf):
+        self.logger.debug("report: Updating table row style")
         pdf.set_text_color(55, 55, 55)
         pdf.set_draw_color(159, 192, 214)
         pdf.set_font('RobotoLight', '', 8)
 
     def setBlueTableTitle(self, pdf):
+        self.logger.debug("report: Updating blue table title")
         pdf.set_font('RobotoLight', '', 14)
         pdf.set_fill_color(255, 255, 255)
         pdf.set_text_color(73, 156, 254)
@@ -236,7 +241,7 @@ class report(controllers.BaseController):
         | key2:   value2 |
         ------------------
         """
-
+        self.logger.debug("report: Generating key:value table")
         # Get max width of all keys
         max_key_width = 20
         max_value_width = 20
@@ -312,6 +317,7 @@ class report(controllers.BaseController):
         - margin - by default: 10
             margin of table rows
         """
+        self.logger.debug("report: Generating table with multiple fields")
         rows_count = 12  # Set row_count with 12 for the agent information size
         table_keys = tables.keys()
         for key in table_keys:
@@ -391,6 +397,7 @@ class report(controllers.BaseController):
                     pdf.line(margin, y, max_width+margin, y)
 
     def addCustomTable(self, customTables, pdf, labels, currentSection):
+        self.logger.debug("report: Adding custom table")
         if customTables:
             for extraTable in customTables:
                 for key, value in extraTable.items():
@@ -449,6 +456,7 @@ class report(controllers.BaseController):
                             customKeyList, customValueList, pdf)
 
     def addSyscheckTable(self, data, pdf, labels, currentSection={}):
+        self.logger.debug("report: Generating syscheck table")
         customKeyList = []
         customValueList = []
         keySet = set()
@@ -475,6 +483,7 @@ class report(controllers.BaseController):
         self.addTables(directoriesTable, pdf, 185, 10)
 
     def addTable(self, data, pdf, labels, currentSection={}):
+        self.logger.debug("report: Adding new table")
         try:
             customTables = []
             keyList = []
@@ -553,6 +562,7 @@ class report(controllers.BaseController):
         return result
 
     def addSubtitle(self, currentSection, pdf):
+        self.logger.debug("report: Adding subtitle")
         self.setBlueTableTitle(pdf)
         if 'subtitle' in currentSection:
             pdf.set_margins(10, 0, 10)
@@ -570,6 +580,7 @@ class report(controllers.BaseController):
             del currentSection['subtitle']
 
     def getSelectedConfigurations(self, selectedOptions):
+        self.logger.debug("report: Obtaining selected configurations")
         selectedConf = [
             {
                 'title': 'Main configurations',
@@ -789,7 +800,7 @@ class report(controllers.BaseController):
         try:
             pdf = PDF('P', 'mm', 'A4')
             first_page = True
-            self.logger.info("Start generating configuration report ")
+            self.logger.info("report: Start generating configuration report ")
             json_acceptable_string = kwargs['data']
             data = jsonbak.loads(json_acceptable_string)
             report_id = datetime.datetime.now().strftime('%Y%m%d%H%M%S')
@@ -1217,7 +1228,6 @@ class report(controllers.BaseController):
         return parsed_data
 
     # Print group info
-
     def print_group_info(self, group, pdf):
         pdf.ln(8)
         pdf.set_font('RobotoLight', '', 11)
@@ -1345,6 +1355,7 @@ class report(controllers.BaseController):
 
     # Cut value string
     def cut_value(self, width, value_string):
+        self.logger.debug("report: Cutting value string")
         num_characters = int(math.ceil(width / 1.50))
         value_splitted = list(str(value_string))
         if len(value_splitted) > num_characters:
@@ -1357,6 +1368,7 @@ class report(controllers.BaseController):
 
     # Split the string
     def split_string(self, width, value_string):
+        self.logger.debug("report: Split string")
         splitted_str = []
         # Number of characters to split the string
         num_characters = int(math.ceil(width / 1.50))
@@ -1387,6 +1399,7 @@ class report(controllers.BaseController):
 
     # Sum arr of numbers
     def sum_numbers_arr(self, arr):
+        self.logger.debug("report: Sum array of numbers")
         total = 0
         for i in arr:
             total = total + i
@@ -1394,6 +1407,7 @@ class report(controllers.BaseController):
 
     # Sum dic of numbers
     def sum_numbers_dic(self, dic):
+        self.logger.debug("report: Sum dictionary of numbers")
         total = 0
         for key in dic.keys():
             total = total + dic[key]
@@ -1401,6 +1415,7 @@ class report(controllers.BaseController):
 
     # Excludes fields from dic
     def exclude_fields(self, fields, dic):
+        self.logger.debug("report: Excluding fields from dictionary")
         dic_to_exclude = dic.copy()
         for f in fields:
             del dic_to_exclude[f]
@@ -1409,6 +1424,7 @@ class report(controllers.BaseController):
     # Check if tables are not empties
 
     def tables_have_info(self, tables):
+        self.logger.debug("report: Checking if table is empty")
         for key in tables.keys():
             if tables[key]:
                 return True
@@ -1416,7 +1432,7 @@ class report(controllers.BaseController):
 
     # Calculates the width of the fields
     def calculate_table_width(self, pdf, table, max_width=190):
-        self.logger.debug("report: Calculating table widths.")
+        self.logger.debug("report: Calculating table widths")
         sizes = {}
         total_width = 0
         fields = table['fields']
