@@ -1,3 +1,5 @@
+/* eslint-disable no-useless-escape */
+/* eslint-disable no-unused-vars */
 /*
  * Wazuh app - Dev tools controller
  * Copyright (C) 2015-2019 Wazuh, Inc.
@@ -23,7 +25,7 @@ define([
   '../../libs/codemirror-conv/show-hint',
   '../../libs/codemirror-conv/querystring-browser/bundle',
   '../../utils/excluded-devtools-autocomplete-keys',
-  'FileSaver'
+  'FileSaver',
 ], function (
   app,
   $,
@@ -49,7 +51,6 @@ define([
      * @param {*} appState
      * @param {*} $notificationService
      * @param {*} $document
-     * @param {*} isAdmin
      */
     constructor(
       $scope,
@@ -58,8 +59,7 @@ define([
       $navigationService,
       $notificationService,
       $appVersionService,
-      $document,
-      isAdmin
+      $document
     ) {
       this.$scope = $scope
       this.appDocuVersion = $appVersionService.getDocumentationVersion()
@@ -72,7 +72,6 @@ define([
       this.linesWithClass = []
       this.widgets = []
       this.multipleKeyPressed = []
-      this.admin = isAdmin
     }
 
     /**
@@ -80,7 +79,7 @@ define([
      */
     $onInit() {
       try {
-        $(this.$document[0]).keydown(e => {
+        $(this.$document[0]).keydown((e) => {
           if (!this.multipleKeyPressed.includes(e.which)) {
             this.multipleKeyPressed.push(e.which)
           }
@@ -95,7 +94,7 @@ define([
         })
 
         // eslint-disable-next-line
-        $(this.$document[0]).keyup(e => {
+        $(this.$document[0]).keyup((_) => {
           this.multipleKeyPressed = []
         })
         this.apiInputBox = CodeMirror.fromTextArea(
@@ -107,13 +106,13 @@ define([
             theme: 'ttcn',
             foldGutter: true,
             styleSelectedText: true,
-            gutters: ['CodeMirror-foldgutter']
+            gutters: ['CodeMirror-foldgutter'],
           }
         )
         // Register plugin for code mirror
         CodeMirror.commands.autocomplete = function (cm) {
           CodeMirror.showHint(cm, CodeMirror.hint.dictionaryHint, {
-            completeSingle: false
+            completeSingle: false,
           })
         }
 
@@ -124,7 +123,7 @@ define([
           const currentGroup = this.calculateWhichGroup()
           if (currentGroup) {
             const hasWidget = this.widgets.filter(
-              item => item.start === currentGroup.start
+              (item) => item.start === currentGroup.start
             )
             if (hasWidget.length)
               this.apiInputBox.removeLineWidget(hasWidget[0].widget)
@@ -149,11 +148,11 @@ define([
             styleActiveLine: true,
             theme: 'ttcn',
             foldGutter: true,
-            gutters: ['CodeMirror-foldgutter']
+            gutters: ['CodeMirror-foldgutter'],
           }
         )
 
-        this.$scope.send = firstTime => this.send(firstTime)
+        this.$scope.send = (firstTime) => this.send(firstTime)
 
         this.$scope.help = () => {
           this.$window.open(
@@ -176,7 +175,7 @@ define([
       try {
         // eslint-disable-next-line
         const blob = new Blob([this.apiOutputBox.getValue()], {
-          type: 'application/json'
+          type: 'application/json',
         })
         saveAs(blob, 'export.json') // eslint-disable-line
       } catch (error) {
@@ -195,16 +194,17 @@ define([
         const tmpgroups = []
         const splitted = currentState
           .split(/[\r\n]+(?=(?:GET|PUT|POST|DELETE|#)\b)/gm)
-          .filter(item => item.replace(/\s/g, '').length)
+          .filter((item) => item.replace(/\s/g, '').length)
         let start = 0
         let end = 0
         let starts = []
         const slen = splitted.length
         for (let i = 0; i < slen; i++) {
           let tmp = splitted[i].split('\n')
-          if (Array.isArray(tmp)) tmp = tmp.filter(item => !item.includes('#'))
+          if (Array.isArray(tmp))
+            tmp = tmp.filter((item) => !item.includes('#'))
           const cursor = this.apiInputBox.getSearchCursor(splitted[i], null, {
-            multiline: true
+            multiline: true,
           })
 
           if (cursor.findNext()) start = cursor.from().line
@@ -265,7 +265,7 @@ define([
             requestText: tmpRequestText,
             requestTextJson: tmpRequestTextJson,
             start,
-            end
+            end,
           })
         }
         starts = []
@@ -349,8 +349,8 @@ define([
               start: item.start,
               widget: this.apiInputBox.addLineWidget(item.start, msg, {
                 coverGutter: false,
-                noHScroll: true
-              })
+                noHScroll: true,
+              }),
             })
           }
         }
@@ -368,7 +368,7 @@ define([
           '/api/autocomplete',
           {}
         )
-        this.apiInputBox.model = !response.error ? response.data : [];
+        this.apiInputBox.model = !response.error ? response.data : []
       } catch (error) {
         this.apiInputBox.model = []
       }
@@ -386,7 +386,7 @@ define([
           !ExcludedIntelliSenseTriggerKeys[(e.keyCode || e.which).toString()]
         ) {
           cm.execCommand('autocomplete', null, {
-            completeSingle: false
+            completeSingle: false,
           })
         }
       })
@@ -394,7 +394,7 @@ define([
       const currentState = this.appState.getCurrentDevTools()
       if (!currentState) {
         const demoStr =
-          'GET /agents?status=Active\n\n#Example comment\nGET /manager/info\n\nGET /syscollector/000/packages?search=ssh\n' +
+          'GET /agents?status=active\n\n#Example comment\nGET /manager/info\n\nGET /syscollector/000/packages?search=ssh\n' +
           JSON.stringify({ limit: 5 }, null, 2)
 
         this.appState.setCurrentDevTools(demoStr)
@@ -405,167 +405,327 @@ define([
       this.groups = this.analyzeGroups()
       const currentGroup = this.calculateWhichGroup()
       this.highlightGroup(currentGroup)
-      const self = this;
+      const self = this
       // Register our custom Codemirror hint plugin.
       CodeMirror.registerHelper('hint', 'dictionaryHint', function (editor) {
         const model = editor.model
         function getDictionary(line, word) {
           let hints = []
           const exp = line.split(/\s+/g)
-          const currentGroup = self.calculateWhichGroup();
+          const currentGroup = self.calculateWhichGroup()
           const editorCursor = editor.getCursor()
           // Get http method, path, query params from API request
-          const [inputRequest, inputHttpMethod, inputPath, inputQueryParamsStart, inputQueryParams] = (currentGroup && currentGroup.requestText && currentGroup.requestText.match(/^(GET|PUT|POST|DELETE) ([^\?]*)(\?)?(\S+)?/)) || [];
+          const [
+            inputRequest,
+            inputHttpMethod,
+            inputPath,
+            inputQueryParamsStart,
+            inputQueryParams,
+          ] =
+            (currentGroup &&
+              currentGroup.requestText &&
+              currentGroup.requestText.match(
+                /^(GET|PUT|POST|DELETE) ([^\?]*)(\?)?(\S+)?/
+              )) ||
+            []
           // Split the input request path as array and lowercase
-          const inputEndpoint = inputPath && inputPath.split('/').filter(item => item).map(item => item.toLowerCase()) || [];
+          const inputEndpoint =
+            (inputPath &&
+              inputPath
+                .split('/')
+                .filter((item) => item)
+                .map((item) => item.toLowerCase())) ||
+            []
           // Get all API endpoints with http method in the request
-          const inputHttpMethodEndpoints = (model.find(item => item.method === inputHttpMethod) || {}).endpoints || [];
+          const inputHttpMethodEndpoints =
+            (model.find((item) => item.method === inputHttpMethod) || {})
+              .endpoints || []
           // Find the API endpoint in the request
           const apiEndpoint = inputHttpMethodEndpoints
-            .map(endpoint => ({ ...endpoint, splitURL: endpoint.name.split('/').filter(item => item) }))
-            .filter(endpoint => endpoint.splitURL.length === inputEndpoint.length)
-            .find(endpoint => endpoint.splitURL.reduce((accum, str, index) => accum && (str.startsWith(':') ? true : str.toLowerCase() === inputEndpoint[index]), true));
+            .map((endpoint) => ({
+              ...endpoint,
+              splitURL: endpoint.name.split('/').filter((item) => item),
+            }))
+            .filter(
+              (endpoint) => endpoint.splitURL.length === inputEndpoint.length
+            )
+            .find((endpoint) =>
+              endpoint.splitURL.reduce(
+                (accum, str, index) =>
+                  accum &&
+                  (str.startsWith(':')
+                    ? true
+                    : str.toLowerCase() === inputEndpoint[index]),
+                true
+              )
+            )
           // Get API endpoint path hints
-          if (exp[0] && currentGroup && currentGroup.start === editorCursor.line && !word.includes('{')) {
+          if (
+            exp[0] &&
+            currentGroup &&
+            currentGroup.start === editorCursor.line &&
+            !word.includes('{')
+          ) {
             // Get hints for requests as: http_method api_path?query_params
             if (inputHttpMethod && inputPath && inputQueryParamsStart) {
               // Split the query params as {key, value}[] where key=value in query param
-              const inputQuery = inputQueryParams && inputQueryParams.split('&').filter(item => item).map(item => {
-                const [key, value] = item.split('=');
-                return { key, value };
-              }) || [];
+              const inputQuery =
+                (inputQueryParams &&
+                  inputQueryParams
+                    .split('&')
+                    .filter((item) => item)
+                    .map((item) => {
+                      const [key, value] = item.split('=')
+                      return { key, value }
+                    })) ||
+                []
               // It is defining query param value query_param=
               const definingQueryParamValue =
                 inputQueryParams && inputQueryParams.includes('&')
-                  ? inputRequest.lastIndexOf('=') > inputRequest.lastIndexOf('&')
-                  : !!(inputQueryParams || '').includes('?') || (inputRequest.lastIndexOf('=') > inputRequest.lastIndexOf('?'));
+                  ? inputRequest.lastIndexOf('=') >
+                    inputRequest.lastIndexOf('&')
+                  : !!(inputQueryParams || '').includes('?') ||
+                    inputRequest.lastIndexOf('=') >
+                      inputRequest.lastIndexOf('?')
 
-              if (!definingQueryParamValue && apiEndpoint && apiEndpoint.query) {
-                const inputQueryPreviousEntriesKeys = inputQuery.filter(query => query.key && query.value).map(query => query.key);
+              if (
+                !definingQueryParamValue &&
+                apiEndpoint &&
+                apiEndpoint.query
+              ) {
+                const inputQueryPreviousEntriesKeys = inputQuery
+                  .filter((query) => query.key && query.value)
+                  .map((query) => query.key)
                 hints = apiEndpoint.query
-                  .filter(query => !inputQueryPreviousEntriesKeys.includes(query.name))
-                  .map(item => `${inputPath}${inputQuery
-                    .filter(query => query.key && query.value)
-                    .reduce((accum, query, index) => `${accum}${index > 0 ? '&' : ''}${query.key}=${query.value}`, '?')}${inputQuery.filter(query => query.key && query.value).length > 0 ? '&' : ''}${item.name}=`)
-
-              };
+                  .filter(
+                    (query) =>
+                      !inputQueryPreviousEntriesKeys.includes(query.name)
+                  )
+                  .map(
+                    (item) =>
+                      `${inputPath}${inputQuery
+                        .filter((query) => query.key && query.value)
+                        .reduce(
+                          (accum, query, index) =>
+                            `${accum}${index > 0 ? '&' : ''}${query.key}=${
+                              query.value
+                            }`,
+                          '?'
+                        )}${
+                        inputQuery.filter((query) => query.key && query.value)
+                          .length > 0
+                          ? '&'
+                          : ''
+                      }${item.name}=`
+                  )
+              }
             } else if (inputHttpMethod) {
               // Get hints for all http method endpoint
               if (!inputPath) {
-                hints = inputHttpMethodEndpoints
-                  .map(endpoint => endpoint.name);
+                hints = inputHttpMethodEndpoints.map(
+                  (endpoint) => endpoint.name
+                )
               } else {
                 // Get hints for requests as: http_method api_path
                 hints = inputHttpMethodEndpoints
-                  .map(endpoint => ({ ...endpoint, splitURL: endpoint.name.split('/').filter(item => item) }))
-                  .filter(endpoint => endpoint.splitURL.reduce((accum, splitPath, index) => {
-                    if (!accum) { return accum };
-                    if (splitPath.startsWith(':') || !inputEndpoint[index] || (inputEndpoint[index] && splitPath.startsWith(inputEndpoint[index]))) {
-                      return true;
-                    };
-                  }, true)
-                  ).map(endpoint => endpoint.splitURL.reduce((accum, splitPath, index) =>
-                    `${accum}/${splitPath.startsWith(':') && inputEndpoint[index] || splitPath}`
-                    , '')
-                  );
+                  .map((endpoint) => ({
+                    ...endpoint,
+                    splitURL: endpoint.name.split('/').filter((item) => item),
+                  }))
+                  .filter((endpoint) =>
+                    endpoint.splitURL.reduce((accum, splitPath, index) => {
+                      if (!accum) {
+                        return accum
+                      }
+                      if (
+                        splitPath.startsWith(':') ||
+                        !inputEndpoint[index] ||
+                        (inputEndpoint[index] &&
+                          splitPath.startsWith(inputEndpoint[index]))
+                      ) {
+                        return true
+                      }
+                    }, true)
+                  )
+                  .map((endpoint) =>
+                    endpoint.splitURL.reduce(
+                      (accum, splitPath, index) =>
+                        `${accum}/${
+                          (splitPath.startsWith(':') && inputEndpoint[index]) ||
+                          splitPath
+                        }`,
+                      ''
+                    )
+                  )
               }
             }
             // Get API endpoint body params hints
-          } else if (currentGroup && currentGroup.requestText && currentGroup.requestTextJson && currentGroup.start < editorCursor.line && currentGroup.end > editorCursor.line) {
-            const reLineStart = /^(\s*)(?:"|')(\S*)(?::)?$/; // Line starts with
-            const spaceLineStart = (line.match(reLineStart) || [])[1] || '';
-            const inputKeyBodyParam = (line.match(reLineStart) || [])[2] || '';
+          } else if (
+            currentGroup &&
+            currentGroup.requestText &&
+            currentGroup.requestTextJson &&
+            currentGroup.start < editorCursor.line &&
+            currentGroup.end > editorCursor.line
+          ) {
+            const reLineStart = /^(\s*)(?:"|')(\S*)(?::)?$/ // Line starts with
+            const spaceLineStart = (line.match(reLineStart) || [])[1] || ''
+            const inputKeyBodyParam = (line.match(reLineStart) || [])[2] || ''
 
             const renderBodyParam = (parameter, spaceLineStart) => {
-              let valueBodyParam = '';
+              let valueBodyParam = ''
               if (parameter.type === 'string') {
                 valueBodyParam = '""'
               } else if (parameter.type === 'array') {
                 valueBodyParam = '[]'
               } else if (parameter.type === 'object') {
-                const paramPropertiesKeys = Object.keys(parameter.properties).sort();
-                const lastIndex = paramPropertiesKeys.length - 1;
-                valueBodyParam = `{\n${paramPropertiesKeys.map((keyProperty, index) => `${spaceLineStart}\t${renderBodyParam({ name: keyProperty, ...parameter.properties[keyProperty] }, spaceLineStart + '\t')}${lastIndex !== index ? ',' : ''}`).join('\n')}\n${spaceLineStart}}`
+                const paramPropertiesKeys = Object.keys(
+                  parameter.properties
+                ).sort()
+                const lastIndex = paramPropertiesKeys.length - 1
+                valueBodyParam = `{\n${paramPropertiesKeys
+                  .map(
+                    (keyProperty, index) =>
+                      `${spaceLineStart}\t${renderBodyParam(
+                        {
+                          name: keyProperty,
+                          ...parameter.properties[keyProperty],
+                        },
+                        spaceLineStart + '\t'
+                      )}${lastIndex !== index ? ',' : ''}`
+                  )
+                  .join('\n')}\n${spaceLineStart}}`
               }
-              return `"${parameter.name}": ${valueBodyParam}`;
-            };
+              return `"${parameter.name}": ${valueBodyParam}`
+            }
 
             const getInnerKeysBodyRequest = () => {
-              let jsonBodyKeyCurrent = [];
+              let jsonBodyKeyCurrent = []
               let jsonBodyKeyCurrentPosition = {
                 start: { line: currentGroup.start, ch: 0 },
-                end: { line: currentGroup.start, ch: 0 }
-              };
-              return ([...Array(currentGroup.end + 1 - currentGroup.start).keys()])
-                .reduce((jsonBodyKeyCursor, lineNumberRange) => {
-                  const editorLineNumber = currentGroup.start + lineNumberRange;
-                  const editorLineContent = editor.getLine(editorLineNumber);
-                  const openBracket = editorLineContent.indexOf('{');
-                  const closeBracket = editorLineContent.indexOf('}');
-                  const keyOpenBracket = (editorLineContent.match(/\s*"(\S+)"\s*:\s*\{/) || [])[1];
-                  keyOpenBracket && jsonBodyKeyCurrent.push(keyOpenBracket) && (jsonBodyKeyCurrentPosition.start = { line: editorLineNumber, ch: openBracket });
+                end: { line: currentGroup.start, ch: 0 },
+              }
+              return [
+                ...Array(currentGroup.end + 1 - currentGroup.start).keys(),
+              ].reduce((jsonBodyKeyCursor, lineNumberRange) => {
+                const editorLineNumber = currentGroup.start + lineNumberRange
+                const editorLineContent = editor.getLine(editorLineNumber)
+                const openBracket = editorLineContent.indexOf('{')
+                const closeBracket = editorLineContent.indexOf('}')
+                const keyOpenBracket = (editorLineContent.match(
+                  /\s*"(\S+)"\s*:\s*\{/
+                ) || [])[1]
+                keyOpenBracket &&
+                  jsonBodyKeyCurrent.push(keyOpenBracket) &&
+                  (jsonBodyKeyCurrentPosition.start = {
+                    line: editorLineNumber,
+                    ch: openBracket,
+                  })
 
-                  closeBracket !== -1 && (jsonBodyKeyCurrentPosition.end = { line: editorLineNumber, ch: closeBracket });
-                  if (!jsonBodyKeyCursor && editorCursor.line > jsonBodyKeyCurrentPosition.start.line
-                    && editorCursor.line < jsonBodyKeyCurrentPosition.end.line) {
-                    jsonBodyKeyCursor = [...jsonBodyKeyCurrent];
-                  };
-                  closeBracket !== -1 && jsonBodyKeyCurrent.pop();
-                  return jsonBodyKeyCursor
-                }, false);
+                closeBracket !== -1 &&
+                  (jsonBodyKeyCurrentPosition.end = {
+                    line: editorLineNumber,
+                    ch: closeBracket,
+                  })
+                if (
+                  !jsonBodyKeyCursor &&
+                  editorCursor.line > jsonBodyKeyCurrentPosition.start.line &&
+                  editorCursor.line < jsonBodyKeyCurrentPosition.end.line
+                ) {
+                  jsonBodyKeyCursor = [...jsonBodyKeyCurrent]
+                }
+                closeBracket !== -1 && jsonBodyKeyCurrent.pop()
+                return jsonBodyKeyCursor
+              }, false)
             }
             const getInnerPropertyBodyParamObject = (object, keys) => {
               if (!keys || !keys.length) {
-                return object;
+                return object
               }
-              const key = keys.shift();
-              if (!object.properties || !object.properties[key] || object.properties[key].type !== 'object') {
-                return [];
+              const key = keys.shift()
+              if (
+                !object.properties ||
+                !object.properties[key] ||
+                object.properties[key].type !== 'object'
+              ) {
+                return []
               }
-              return getInnerPropertyBodyParamObject(object.properties[key], keys);
-            };
+              return getInnerPropertyBodyParamObject(
+                object.properties[key],
+                keys
+              )
+            }
 
             if (apiEndpoint && apiEndpoint.body && reLineStart.test(line)) {
-              let inputBodyPreviousKeys;
-              let paramsBody = apiEndpoint.body;
-              let requestBodyCursorKeys;
+              let inputBodyPreviousKeys
+              let paramsBody = apiEndpoint.body
+              let requestBodyCursorKeys
               if (apiEndpoint.body[0].type === 'object') {
-                requestBodyCursorKeys = getInnerKeysBodyRequest();
-                const paramInnerBody = getInnerPropertyBodyParamObject(apiEndpoint.body[0], [...requestBodyCursorKeys]);
-                paramsBody = Object.keys(paramInnerBody.properties).sort().map(keyBodyParam => ({ name: keyBodyParam, ...paramInnerBody.properties[keyBodyParam] }));
-              };
+                requestBodyCursorKeys = getInnerKeysBodyRequest()
+                const paramInnerBody = getInnerPropertyBodyParamObject(
+                  apiEndpoint.body[0],
+                  [...requestBodyCursorKeys]
+                )
+                paramsBody = Object.keys(paramInnerBody.properties)
+                  .sort()
+                  .map((keyBodyParam) => ({
+                    name: keyBodyParam,
+                    ...paramInnerBody.properties[keyBodyParam],
+                  }))
+              }
               try {
-                const bodySanitizedBodyParam = currentGroup.requestTextJson.replace(/(,\s*"\S*\s*)\}/g, '}');
-                inputBodyPreviousKeys = Object.keys((requestBodyCursorKeys || []).reduce((acumm, key) => acumm[key], JSON.parse(bodySanitizedBodyParam)));
+                const bodySanitizedBodyParam =
+                  currentGroup.requestTextJson.replace(/(,\s*"\S*\s*)\}/g, '}')
+                inputBodyPreviousKeys = Object.keys(
+                  (requestBodyCursorKeys || []).reduce(
+                    (acumm, key) => acumm[key],
+                    JSON.parse(bodySanitizedBodyParam)
+                  )
+                )
               } catch (error) {
-                inputBodyPreviousKeys = [];
-              };
+                inputBodyPreviousKeys = []
+              }
 
               hints = paramsBody
-                .filter(bodyParam => !inputBodyPreviousKeys.includes(bodyParam.name) && bodyParam.name && (inputKeyBodyParam ? bodyParam.name.includes(inputKeyBodyParam) : true))
-                .map(bodyParam => ({
+                .filter(
+                  (bodyParam) =>
+                    !inputBodyPreviousKeys.includes(bodyParam.name) &&
+                    bodyParam.name &&
+                    (inputKeyBodyParam
+                      ? bodyParam.name.includes(inputKeyBodyParam)
+                      : true)
+                )
+                .map((bodyParam) => ({
                   text: renderBodyParam(bodyParam, spaceLineStart),
                   _moveCursor: ['string', 'array'].includes(bodyParam.type),
                   displayText: bodyParam.name,
                   bodyParam,
                   hint: (cm, self, data) => {
-                    editor.replaceRange(line.replace(/\S+/, '') + data.text, { line: editorCursor.line, ch: editorCursor.ch }, { line: editorCursor.line, ch: 0 });
-                    const textReplacedLine = editor.getLine(editorCursor.line);
-                    editor.setCursor({ line: editorCursor.line, ch: data._moveCursor ? textReplacedLine.length - 1 : textReplacedLine.length });
-                  }
-                }));
-            };
+                    editor.replaceRange(
+                      line.replace(/\S+/, '') + data.text,
+                      { line: editorCursor.line, ch: editorCursor.ch },
+                      { line: editorCursor.line, ch: 0 }
+                    )
+                    const textReplacedLine = editor.getLine(editorCursor.line)
+                    editor.setCursor({
+                      line: editorCursor.line,
+                      ch: data._moveCursor
+                        ? textReplacedLine.length - 1
+                        : textReplacedLine.length,
+                    })
+                  },
+                }))
+            }
           } else {
-            hints = model.map(a => a.method);
+            hints = model.map((a) => a.method)
           }
-          const final_hints = hints.map(chain => {
-            let t = 0;
-            return chain = chain.replace(/\?/g, (match) => {
-              t++;
+          const final_hints = hints.map((chain) => {
+            let t = 0
+            return (chain = chain.replace(/\?/g, (match) => {
+              t++
               return t > 1 ? '' : match
-            });
+            }))
           })
-          return final_hints;
+          return final_hints
         }
 
         const cur = editor.getCursor()
@@ -581,11 +741,11 @@ define([
           list: (!curWord
             ? []
             : getDictionary(curLine, curWord).filter(function (item) {
-              return item.toUpperCase().includes(curWord.toUpperCase())
-            })
+                return item.toUpperCase().includes(curWord.toUpperCase())
+              })
           ).sort(),
           from: CodeMirror.Pos(cur.line, start),
-          to: CodeMirror.Pos(cur.line, end)
+          to: CodeMirror.Pos(cur.line, end),
         }
       })
       $('.wz-dev-column-separator').mousedown(function (e) {
@@ -613,7 +773,7 @@ define([
         )
       }
 
-      setTimeout(x => {
+      setTimeout((_) => {
         this.apiInputBox.refresh()
         this.apiOutputBox.refresh()
       }, 1)
@@ -625,54 +785,96 @@ define([
      */
     calculateWhichGroup(firstTime) {
       try {
-        const selection = this.apiInputBox.getCursor();
+        const selection = this.apiInputBox.getCursor()
         const desiredGroup = firstTime
-          ? this.groups.filter(item => item.requestText)
+          ? this.groups.filter((item) => item.requestText)
           : this.groups.filter(
-            item =>
-              item.requestText &&
-              (item.end >= selection.line && item.start <= selection.line)
-          );
+              (item) =>
+                item.requestText &&
+                item.end >= selection.line &&
+                item.start <= selection.line
+            )
 
         // Place play button at first line from the selected group
         const cords = this.apiInputBox.cursorCoords({
           line: desiredGroup[0].start,
-          ch: 0
-        });
-        if (!$('#play_button').is(':visible')) $('#play_button').show();
-        if (!$('#wazuh_dev_tools_documentation').is(':visible')) $('#wazuh_dev_tools_documentation').show();
-        const currentPlayButton = $('#play_button').offset();
+          ch: 0,
+        })
+        if (!$('#play_button').is(':visible')) $('#play_button').show()
+        if (!$('#wazuh_dev_tools_documentation').is(':visible'))
+          $('#wazuh_dev_tools_documentation').show()
+        const currentPlayButton = $('#play_button').offset()
         $('#play_button').offset({
           top: cords.top,
-          left: currentPlayButton.left
-        });
+          left: currentPlayButton.left,
+        })
         $('#wazuh_dev_tools_documentation').offset({
-          top: cords.top
-        });
-        if (firstTime) this.highlightGroup(desiredGroup[0]);
+          top: cords.top,
+        })
+        if (firstTime) this.highlightGroup(desiredGroup[0])
         if (desiredGroup[0]) {
-          const [inputRequest, inputHttpMethod, inputPath, inputQueryParamsStart, inputQueryParams] = (desiredGroup[0] && desiredGroup[0].requestText && desiredGroup[0].requestText.match(/^(GET|PUT|POST|DELETE) ([^\?]*)(\?)?(\S+)?/)) || [];
+          const [
+            inputRequest,
+            inputHttpMethod,
+            inputPath,
+            inputQueryParamsStart,
+            inputQueryParams,
+          ] =
+            (desiredGroup[0] &&
+              desiredGroup[0].requestText &&
+              desiredGroup[0].requestText.match(
+                /^(GET|PUT|POST|DELETE) ([^\?]*)(\?)?(\S+)?/
+              )) ||
+            []
           // Split the input request path as array and lowercase
-          const inputEndpoint = inputPath && inputPath.split('/').filter(item => item).map(item => item.toLowerCase()) || [];
+          const inputEndpoint =
+            (inputPath &&
+              inputPath
+                .split('/')
+                .filter((item) => item)
+                .map((item) => item.toLowerCase())) ||
+            []
           // Get all API endpoints with http method in the request
-          const inputHttpMethodEndpoints = (this.apiInputBox.model.find(item => item.method === inputHttpMethod) || {}).endpoints || [];
+          const inputHttpMethodEndpoints =
+            (
+              this.apiInputBox.model.find(
+                (item) => item.method === inputHttpMethod
+              ) || {}
+            ).endpoints || []
           // Find the API endpoint in the request
           const apiEndpoint = inputHttpMethodEndpoints
-            .map(endpoint => ({ ...endpoint, splitURL: endpoint.name.split('/').filter(item => item) }))
-            .filter(endpoint => endpoint.splitURL.length === inputEndpoint.length)
-            .find(endpoint => endpoint.splitURL.reduce((accum, str, index) => accum && (str.startsWith(':') ? true : str.toLowerCase() === inputEndpoint[index]), true));
+            .map((endpoint) => ({
+              ...endpoint,
+              splitURL: endpoint.name.split('/').filter((item) => item),
+            }))
+            .filter(
+              (endpoint) => endpoint.splitURL.length === inputEndpoint.length
+            )
+            .find((endpoint) =>
+              endpoint.splitURL.reduce(
+                (accum, str, index) =>
+                  accum &&
+                  (str.startsWith(':')
+                    ? true
+                    : str.toLowerCase() === inputEndpoint[index]),
+                true
+              )
+            )
           if (apiEndpoint && apiEndpoint.documentation) {
-            const docuUrl = apiEndpoint.documentation.replace('/current/',`/${this.appDocuVersion}/`)
-            $('#wazuh_dev_tools_documentation').attr('href', docuUrl).show();
+            const docuUrl = apiEndpoint.documentation.replace(
+              '/current/',
+              `/${this.appDocuVersion}/`
+            )
+            $('#wazuh_dev_tools_documentation').attr('href', docuUrl).show()
           } else {
-            $('#wazuh_dev_tools_documentation').attr('href', '').hide();
+            $('#wazuh_dev_tools_documentation').attr('href', '').hide()
           }
         }
-        return desiredGroup[0];
+        return desiredGroup[0]
       } catch (error) {
-        $('#play_button').hide();
-        $('#wazuh_dev_tools_documentation').hide();
-        return null;
+        $('#play_button').hide()
+        $('#wazuh_dev_tools_documentation').hide()
+        return null
       }
     }
 
@@ -688,40 +890,34 @@ define([
           if (firstTime) {
             const cords = this.apiInputBox.cursorCoords({
               line: desiredGroup.start,
-              ch: 0
+              ch: 0,
             })
             const currentPlayButton = $('#play_button').offset()
             $('#play_button').offset({
               top: cords.top + 35,
-              left: currentPlayButton.left
+              left: currentPlayButton.left,
             })
           }
 
           const affectedGroups = this.checkJsonParseError()
           const filteredAffectedGroups = affectedGroups.filter(
-            item => item === desiredGroup.requestText
+            (item) => item === desiredGroup.requestText
           )
           if (filteredAffectedGroups.length) {
             this.apiOutputBox.setValue('Error parsing JSON query')
             return
           }
 
-          let method = ''
-          if (this.admin) {
-            method = desiredGroup.requestText.startsWith('GET')
-              ? 'GET'
-              : desiredGroup.requestText.startsWith('POST')
-                ? 'POST'
-                : desiredGroup.requestText.startsWith('PUT')
-                  ? 'PUT'
-                  : desiredGroup.requestText.startsWith('DELETE')
-                    ? 'DELETE'
-                    : 'GET'
-          } else {
-            if (desiredGroup.requestText.startsWith('GET')) method = 'GET'
-            else
-              return this.apiOutputBox.setValue('3029 - Allowed method: [GET]')
-          }
+          const method = desiredGroup.requestText.startsWith('GET')
+            ? 'GET'
+            : desiredGroup.requestText.startsWith('POST')
+            ? 'POST'
+            : desiredGroup.requestText.startsWith('PUT')
+            ? 'PUT'
+            : desiredGroup.requestText.startsWith('DELETE')
+            ? 'DELETE'
+            : 'GET'
+
           let requestCopy = desiredGroup.requestText.includes(method)
             ? desiredGroup.requestText.split(method)[1].trim()
             : desiredGroup.requestText
@@ -762,7 +958,7 @@ define([
             path = req.includes('?') ? req.split('?')[0] : req
           } else {
             if (extra) {
-              Object.keys(JSONraw).map(k => {
+              Object.keys(JSONraw).map((k) => {
                 if (extra[k]) {
                   delete JSONraw[k]
                 }
@@ -771,8 +967,8 @@ define([
             path =
               typeof JSONraw === 'object' && Object.keys(JSONraw).length
                 ? `${req}${req.includes('?') ? '&' : '?'}${queryString.unescape(
-                  queryString.stringify(JSONraw)
-                )}`
+                    queryString.stringify(JSONraw)
+                  )}`
                 : req
             JSONraw = {}
           }
@@ -782,14 +978,14 @@ define([
             const output = await this.request.apiReq(path, JSONraw, method)
             const result = output.data
               ? JSON.stringify((output || {}).data || {}, null, 2).replace(
-                /\\\\/g,
-                '\\'
-              )
+                  /\\\\/g,
+                  '\\'
+                )
               : output.data.message || 'Unkown error'
             this.apiOutputBox.setValue(result)
           }
         }
-        ; (firstTime || !desiredGroup) && this.apiOutputBox.setValue('Welcome!') // eslint-disable-line
+        ;(firstTime || !desiredGroup) && this.apiOutputBox.setValue('Welcome!') // eslint-disable-line
       } catch (error) {
         if ((error || {}).status === -1) {
           return this.apiOutputBox.setValue(
